==> ideaIC-173.4301.1-sources.jar: org/jetbrains/idea/svn/api/UrlMappingRepositoryProvider.java <==
/*
 * Copyright 2000-2013 JetBrains s.r.o.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.jetbrains.idea.svn.api;

import org.jetbrains.annotations.NotNull;
import org.jetbrains.annotations.Nullable;
import org.jetbrains.idea.svn.RootUrlInfo;
import org.jetbrains.idea.svn.SvnVcs;
import org.tmatesoft.svn.core.wc2.SvnTarget;

/**
* @author Konstantin Kolosovsky.
*/
public class UrlMappingRepositoryProvider extends BaseRepositoryProvider {

  public UrlMappingRepositoryProvider(@NotNull SvnVcs vcs, @NotNull SvnTarget target) {
    super(vcs, target);
  }

  @Nullable
  @Override
  public Repository get() {
    RootUrlInfo rootInfo = null;

    if (!myVcs.getProject().isDefault()) {
      rootInfo = myTarget.isFile()
                 ? myVcs.getSvnFileUrlMapping().getWcRootForFilePath(myTarget.getFile())
                 : myVcs.getSvnFileUrlMapping().getWcRootForUrl(myTarget.getURL());
    }

    return rootInfo != null ? new Repository(rootInfo.getRepositoryUrl()) : null;
  }
}

==> ideaIC-2017.2.6-sources.jar: org/jetbrains/idea/svn/api/UrlMappingRepositoryProvider.java <==
/*
 * Copyright 2000-2013 JetBrains s.r.o.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.jetbrains.idea.svn.api;

import org.jetbrains.annotations.NotNull;
import org.jetbrains.annotations.Nullable;
import org.jetbrains.idea.svn.RootUrlInfo;
import org.jetbrains.idea.svn.SvnVcs;
import org.tmatesoft.svn.core.wc2.SvnTarget;

/**
* @author Konstantin Kolosovsky.
*/
public class UrlMappingRepositoryProvider extends BaseRepositoryProvider {

  public UrlMappingRepositoryProvider(@NotNull SvnVcs vcs, @NotNull SvnTarget target) {
    super(vcs, target);
  }

  @Nullable
  @Override
  public Repository get() {
    RootUrlInfo rootInfo = null;

    if (!myVcs.getProject().isDefault()) {
      rootInfo = myTarget.isFile()
                 ? myVcs.getSvnFileUrlMapping().getWcRootForFilePath(myTarget.getFile())
                 : myVcs.getSvnFileUrlMapping().getWcRootForUrl(myTarget.getURL().toDecodedString());
    }

    return rootInfo != null ? new Repository(rootInfo.getRepositoryUrlUrl()) : null;
  }
}
